/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Community System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2001 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.core.impl;

import java.sql.*;
import java.util.*;
import com.silverwrist.venice.core.*;
import com.silverwrist.venice.db.*;

class FrontPageViewConfigImpl implements FrontPageViewConfig, Stashable
{
  private int my_uid;
  private int num_cols;
  private Vector v_parts = new Vector();
  private Vector v_params = new Vector();
  private boolean is_modified = false;

  FrontPageViewConfigImpl(Connection conn, int uid, int max_cols) throws DataException, SQLException
  {
    my_uid = uid;
    num_cols = max_cols;
    StringBuffer sql = new StringBuffer("SELECT row, col, partid, param FROM topconfig WHERE uid = ");
    sql.append(uid).append(';');

    Statement stmt = conn.createStatement();
    ResultSet rs = stmt.executeQuery(sql.toString());
    while (rs.next())
    { // make sure the column is in range first
      int col = rs.getInt("col");
      if ((col>=0) && (col<num_cols))
      { // get the row and find out how far down we have to go in the vector
	int row = rs.getInt("row");
	if (row>=0)
	{ // now look for the right arrays to store into
	  String[] a_part = null;
	  String[] a_param = null;

	  if (row>=v_parts.size())
	  { // need to extend the vector contents
	    while (row>=v_parts.size())
	    { // append new arrays onto the config
	      a_part = new String[num_cols];
	      a_param = new String[num_cols];
	      for (int i=0; i<num_cols; i++)
	      { // nuke the new arrays
		a_part[i] = null;
		a_param[i] = null;

	      } // end for

	      v_parts.addElement(a_part);
	      v_params.addElement(a_param);

	    } // end while

	  } // end if
	  else
	  { // just fetch the existing arrays
	    a_part = (String[])(v_parts.elementAt(row));
	    a_param = (String[])(v_params.elementAt(row));

	  } // end else

	  // and now save off the recordset data
	  a_part[col] = rs.getString("partid");
	  a_param[col] = rs.getString("param");

	} // end if

      } // end if

    } // end while

  } // end constructor

  public int getNumRows()
  {
    return v_parts.size();

  } // end getNumRows

  public int getNumColumns()
  {
    return num_cols;

  } // end getNumCols

  public String getPartID(int row, int column)
  {
    if ((row<0) || (row>=v_parts.size()))
      throw new IndexOutOfBoundsException("invalid row specified to FrontPageViewConfig.getPartID");
    if ((column<0) || (column>=num_cols))
      throw new IndexOutOfBoundsException("invalid column specified to FrontPageViewConfig.getPartID");

    String[] array = (String[])(v_parts.elementAt(row));
    return array[column];

  } // end getPartID

  public void setPartID(int row, int column, String partid)
  {
    if (row<0)
      throw new IndexOutOfBoundsException("invalid row specified to FrontPageViewConfig.setPartID");
    if ((column<0) || (column>=num_cols))
      throw new IndexOutOfBoundsException("invalid column specified to FrontPageViewConfig.setPartID");

    String[] a_part = null;
    String[] a_param = null;

    if (row>=v_parts.size())
    { // need to extend the vector contents
      while (row>=v_parts.size())
      { // append new arrays onto the config
	a_part = new String[num_cols];
	a_param = new String[num_cols];
	for (int i=0; i<num_cols; i++)
	{ // nuke the new arrays
	  a_part[i] = null;
	  a_param[i] = null;

	} // end for

	v_parts.addElement(a_part);
	v_params.addElement(a_param);

      } // end while

    } // end if
    else // just fetch the existing array
      a_part = (String[])(v_parts.elementAt(row));

    a_part[column] = partid;
    is_modified = true;

  } // end setPartID

  public String getParameter(int row, int column)
  {
    if ((row<0) || (row>=v_params.size()))
      throw new IndexOutOfBoundsException("invalid row specified to FrontPageViewConfig.getParameter");
    if ((column<0) || (column>=num_cols))
      throw new IndexOutOfBoundsException("invalid column specified to FrontPageViewConfig.getParameter");

    String[] array = (String[])(v_params.elementAt(row));
    return array[column];

  } // end getParameter

  public void setParameter(int row, int column, String param)
  {
    if (row<0)
      throw new IndexOutOfBoundsException("invalid row specified to FrontPageViewConfig.setParameter");
    if ((column<0) || (column>=num_cols))
      throw new IndexOutOfBoundsException("invalid column specified to FrontPageViewConfig.setParameter");

    String[] a_part = null;
    String[] a_param = null;

    if (row>=v_parts.size())
    { // need to extend the vector contents
      while (row>=v_parts.size())
      { // append new arrays onto the config
	a_part = new String[num_cols];
	a_param = new String[num_cols];
	for (int i=0; i<num_cols; i++)
	{ // nuke the new arrays
	  a_part[i] = null;
	  a_param[i] = null;

	} // end for

	v_parts.addElement(a_part);
	v_params.addElement(a_param);

      } // end while

    } // end if
    else // just fetch the existing array
      a_param = (String[])(v_params.elementAt(row));

    a_param[column] = param;
    is_modified = true;

  } // end setParameter

  public boolean getModified()
  {
    return is_modified;

  } // end getModified

  public int getStashableUID()
  {
    return my_uid;

  } // end getStashableUID

  public void stash(Connection conn) throws SQLException
  {
    StringBuffer buf = new StringBuffer();
    for (int row=0; row<v_parts.size(); row++)
    { // retrieve the row arrays first
      String[] a_part = (String[])(v_parts.elementAt(row));
      String[] a_param = (String[])(v_params.elementAt(row));

      for (int col=0; col<num_cols; col++)
      { // add to the list as long as the part isn't NULL
	if (a_part[col]!=null)
	{ // append this set of values to the INSERT we're going to make later
	  if (buf.length()==0)
	    buf.append("INSERT INTO topconfig (uid, row, col, partid, param) VALUES ");
	  else
	    buf.append(", ");
	  buf.append('(').append(my_uid).append(", ").append(row).append(", ").append(col).append(", ");
	  buf.append(SQLUtil.encodeStringArg(a_part[col])).append(", ");
	  buf.append(SQLUtil.encodeStringArg(a_param[col])).append(')');
	  
	} // end if

      } // end for (each column)

    } // end for (each row)

    String insert_cmd = null;
    if (buf.length()>0)
    { // we've got the insert command
      buf.append(';');
      insert_cmd = buf.toString();
      buf.setLength(0);

    } // end if

    // now create the DELETE command
    buf.append("DELETE FROM topconfig WHERE uid = ").append(my_uid).append(';');

    // we need to lock the topconfig table while we do this
    Statement stmt = conn.createStatement();
    stmt.executeUpdate("LOCK TABLES topconfig WRITE;");

    try
    { // delete all existing records
      stmt.executeUpdate(buf.toString());
      
      // now insert the new records
      if (insert_cmd!=null)
	stmt.executeUpdate(insert_cmd);

    } // end try
    finally
    { // make sure to unlock the tables when we're done
      Statement ulk_stmt = conn.createStatement();
      ulk_stmt.executeUpdate("UNLOCK TABLES;");

    } // end finally

  } // end stash

} // end class FrontPageViewConfigImpl
