/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Community System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2001 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.servlets.format;

import java.io.Writer;
import java.io.IOException;
import java.util.List;
import java.util.Iterator;
import com.silverwrist.venice.core.SIGContext;
import com.silverwrist.venice.core.UserContext;
import com.silverwrist.venice.core.DataException;

public class TCPanelSIGs extends TCStandardPanel
{
  private List my_sigs = null;

  public TCPanelSIGs()
  {
    super("Your SIGs:",null);
    addButton("bn_manage.gif","Manage",null,true,80,24);
    addButton("bn_create_new.gif","Create New","sigops?cmd=C",true,80,24);

  } // end constructor

  protected TCPanelSIGs(TCPanelSIGs other)
  {
    super(other);

  } // end constructor

  public void renderContent(Writer out, RenderData rdat) throws IOException
  {
    out.write(rdat.getStdFontTag(null,2) + "\n");
    if (my_sigs.size()>0)
    { // display the list of available SIGs
      out.write("<UL>\n");

      Iterator it = my_sigs.iterator();
      while (it.hasNext())
      { // display the names of the SIGs one by one
	SIGContext sig = (SIGContext)(it.next());
	// TODO: make this fancier than just an unordered list
	out.write("<LI><B><A HREF=\"" + rdat.getEncodedServletPath("sig/" + sig.getAlias())
		  + "\">" + sig.getName() + "</A></B>");
	if (sig.isAdmin())
	  out.write("&nbsp;<IMG SRC=\"" + rdat.getFullImagePath("tag_host.gif")
		    + "\" ALT=\"Host!\" BORDER=0 WIDTH=40 HEIGHT=20>");
	out.write("</LI>\n");

      } // end while

      out.write("</UL>\n");

    } // end if
    else
      out.write("<EM>You are not a member of any SIGs.</EM>\n");
      
    out.write("</FONT>\n");

  } // end renderContent

  public void configure(UserContext uc, String parameter) throws DataException
  {
    super.configure(uc,parameter);
    if (!(uc.isLoggedIn()))
      setTitle("Featured SIGs:");
    my_sigs = uc.getMemberSIGs();

  } // end configure

  public Object clone()
  {
    return new TCPanelSIGs(this);

  } // end clone

} // end class TCPanelSIGs
